// Persistence of Vision Ray Tracer Scene Description File
// File: templ_1.pov
// Vers: 3
// Desc: This file demonstrates the use of TXTS2POV with a template file.
//       To create output files from this file you have to call TXTS2POV
//       like this: txts2pov inputfile /ttempl_1 /n27 ...
// Date: 11/16/1997
// Auth: Friedemann Schmidt, friedemann@stones.com

// Perhaps you have to delete one or more of
// the following include lines if they conflict
// with the read texture includes.
#version 3.0
#include "colors.inc"
#include "textures.inc"
#include "metals.inc"
#include "glass.inc"
#include "woods.inc"
#include "stones.inc"
#include "stoneold.inc"

#declare Stack = union {
  box { -1, 1 }
  cylinder { -y, y, 1 translate 2*y}
  sphere{<0, 4, 0>, 1}
}

#declare ScenePos = -10000
#declare LabelMaxWidth = 2.9

#declare i = 1
#while (i <= 27)

  // ********* #include txts2pov - this line would be replaced by TXTS2POV

  #declare LabelText1 = TextureFile
  #declare LabelText2 = TextureName

  #if (TextureNr <= TexturesCount)
    #declare X = -12+mod(i-1, 9)*3
    #declare Y = 10.5 - int((i-1)/9)*7
    object {
      Stack
      texture{ Texture }
      translate <X, Y, 0> + ScenePos
      hollow
    }

    #declare LabelFontScale = 1
    #declare LabelWidth = max(strlen(LabelText1)*0.6*LabelFontScale, strlen(LabelText2)*0.6*LabelFontScale)
    #if (LabelWidth > LabelMaxWidth)
      #declare LabelFontScale = (LabelMaxWidth)/(LabelWidth)*LabelFontScale
      #declare LabelWidth = LabelMaxWidth
    #end
    #declare LabelFontScale = LabelFontScale*0.9
    #declare LabelHeight = 2*LabelFontScale
    union {
      box {
        <-LabelWidth/2, -LabelHeight/2, 0>, <LabelWidth/2, 0, 0.1>
        pigment { color rgb <1, 1, 1> }
        finish { ambient 0 diffuse 1 }
      }
      box {
        <-LabelWidth/2, 0, 0>, <LabelWidth/2, LabelHeight/2, 0.1>
        pigment { color rgb <0, 0, 0> }
        finish { ambient 0 diffuse 1 }
      }
      text {
        ttf "COURBD.TTF",
        LabelText1,
        0.1, 0
        translate <-strlen(LabelText1)*0.3, -0.6/2, -0.1>
        scale LabelFontScale
        translate LabelHeight/4*y
        pigment { color rgb <1, 1, 1> }
        finish { ambient 0 diffuse 1 }
      }
      text {
        ttf "COURBD.TTF",
        LabelText2,
        0.1, 0
        translate <-strlen(LabelText2)*0.3, -0.6/2, -0.1>
        scale LabelFontScale
        translate -LabelHeight/4*y
        pigment { color rgb <0, 0, 0 > }
        finish { ambient 0 diffuse 1 }
      }
      translate <X, Y-1, -1.5> + ScenePos
    }
  #end
  #declare i = i + 1
  #declare TextureNr = TextureNr + 1
#end

camera {
   location <0, 5, -30>
   direction <0, 0,  1.35>
   look_at 5*y
   translate ScenePos
}

light_source { <0, 0, -1000> + ScenePos color LightGray }

light_source {<150, 50, -200> + ScenePos color LightGray}

plane { z, 1.1 pigment {White} hollow translate ScenePos}
